/*  _____ _
 * |_   _| |_  _ _ ___ ___ _ __  __ _
 *   | | | ' \| '_/ -_) -_) '  \/ _` |_
 *   |_| |_||_|_| \___\___|_|_|_\__,_(_)
 *
 * Threema for Android
 * Copyright (c) 2017-2024 Threema GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package ch.threema.app.utils;

import android.content.Intent;
import android.os.BatteryManager;
import androidx.annotation.Nullable;

public class BatteryStatusUtil {

	/**
	 * Return whether the device is charging or not.
	 *
	 * @param intent An intent from a battery status broadcast.
	 */
	@Nullable
	public static Boolean isCharging(Intent intent) {
		final int status = intent.getIntExtra(BatteryManager.EXTRA_STATUS, -1);
		if (status == -1) {
			return null;
		}
		return status == BatteryManager.BATTERY_STATUS_CHARGING ||
		       status == BatteryManager.BATTERY_STATUS_FULL;
	}

	@Nullable
	public static Integer getPercent(Intent intent) {
		final int level = intent.getIntExtra(BatteryManager.EXTRA_LEVEL, -1);
		final int scale = intent.getIntExtra(BatteryManager.EXTRA_SCALE, -1);
		if (level == -1 || scale == -1) {
			return null;
		}
		return level * 100 / scale;
	}

}
