/*  _____ _
 * |_   _| |_  _ _ ___ ___ _ __  __ _
 *   | | | ' \| '_/ -_) -_) '  \/ _` |_
 *   |_| |_||_|_| \___\___|_|_|_\__,_(_)
 *
 * Threema for Android
 * Copyright (c) 2015-2024 Threema GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package ch.threema.app.utils;

import android.content.Context;
import android.view.View;
import android.view.ViewTreeObserver;
import android.view.inputmethod.InputMethodManager;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.UiThread;

public class EditTextUtil {
	@UiThread
	public static void focusWindowAndShowSoftKeyboard(@Nullable View view) {
		if (view == null) {
			return;
		}
		focusWindow(view, () -> {
			if (view.isFocused()) {
				// post in case window focus changed, but InputMethodManager is not setup yet.
				view.post(() -> showSoftKeyboard(view));
			}
		});
	}

	@UiThread
	public static void showSoftKeyboard(@Nullable View view) {
		if (view == null) {
			return;
		}
		InputMethodManager inputManager = (InputMethodManager)view.getContext().getSystemService(Context.INPUT_METHOD_SERVICE);
		inputManager.showSoftInput(view, InputMethodManager.SHOW_IMPLICIT);
	}

	@UiThread
	public static void hideSoftKeyboard(@Nullable View view) {
		if (view == null) {
			return;
		}
		InputMethodManager imm = (InputMethodManager) view.getContext().getSystemService(Context.INPUT_METHOD_SERVICE);
		if (!imm.isActive()) {
			return;
		}
		imm.hideSoftInputFromWindow(view.getWindowToken(), 0);
	}


	private static void focusWindow(@NonNull View view, Runnable onFocus) {
		view.requestFocus();
		if (view.hasWindowFocus()) {
			onFocus.run();
		} else {
			// window needs to have focus to show keyboard
			view.getViewTreeObserver().addOnWindowFocusChangeListener(new ViewTreeObserver.OnWindowFocusChangeListener() {
				@Override
				public void onWindowFocusChanged(boolean hasFocus) {
					if (hasFocus) {
						onFocus.run();
						view.getViewTreeObserver().removeOnWindowFocusChangeListener(this);
					}
				}
			});
		}
	}
}
